
Changelog
*********


sphinx-rst-builder 0.0.3 (18. January 2020)
===========================================

* Fix changelog


sphinx-rst-builder 0.0.2 (18. January 2020)
===========================================

* Add bumpversion config to repo

* Add new config value *rst_preserve_code_black_flags* to retain
  (some) flage to ``.. code-block:``

* Preserve ``.. code-block::``. (`#2 <https://github.com/davidfritzsche/sphinx-rst-builder/pull/2>`_)

* Drop the overridden ``relative_uri()``
  method. (`#1 <https://github.com/davidfritzsche/sphinx-rst-builder/pull/1>`_)


sphinx-rst-builder 0.0.1 (21 June 2019)
=======================================

* Renamed from sphinxcontrib.restbuilder to sphinx-rst-builder

* Code location: `https://github.com/davidfritzsche/sphinx-rst-builder <https://github.com/davidfritzsche/sphinx-rst-builder>`_


restbuilder 0.2 (7 June 2018)
=============================

* Code moved to `https://gitub.com/sphinx-contrib/restbuilder <https://gitub.com/sphinx-contrib/restbuilder>`_

* Python 3 compatible (Nicola Musatti)

* Adhere to rst_indent-specified indentation (Matthew Planchard)

* Fixed issue where links were converted to plaintext (Matthew Planchard)


restbuilder 0.1 (25 August 2013)
================================

* Code submitted to sphinx-contrib
  `https://bitbucket.org/birkenfeld/sphinx-contrib <https://bitbucket.org/birkenfeld/sphinx-contrib>`_

* Released as sphinxcontrib-restbuilder

* Added basic documentation

* Unsupported/unknown tags are not printed, but send to log facility.


restbuilder (no version) (28 April 2012)
========================================

* First release as port of a documentation generator in the NBT package
  `https://github.com/twoolie/NBT/commit/eefbd26c422a0e5f3c89e84fabcfb951a11722b0 <https://github.com/twoolie/NBT/commit/eefbd26c422a0e5f3c89e84fabcfb951a11722b0>`_
